==> dojo_1.5.0+dfsg.orig.tar.gz: dojo-release-1.5.0-src+dfsg/dijit/_editor/nls/cs/commands.js <==
({
	'bold': 'Tučné',
	'copy': 'Kopírovat',
	'cut': 'Vyjmout',
	'delete': 'Odstranit',
	'indent': 'Odsadit',
	'insertHorizontalRule': 'Vodorovná čára',
	'insertOrderedList': 'Číslovaný seznam',
	'insertUnorderedList': 'Seznam s odrážkami',
	'italic': 'Kurzíva',
	'justifyCenter': 'Zarovnat na střed',
	'justifyFull': 'Do bloku',
	'justifyLeft': 'Zarovnat vlevo',
	'justifyRight': 'Zarovnat vpravo',
	'outdent': 'Předsadit',
	'paste': 'Vložit',
	'redo': 'Opakovat',
	'removeFormat': 'Odebrat formát',
	'selectAll': 'Vybrat vše',
	'strikethrough': 'Přeškrtnutí',
	'subscript': 'Dolní index',
	'superscript': 'Horní index',
	'underline': 'Podtržení',
	'undo': 'Zpět',
	'unlink': 'Odebrat odkaz',
	'createLink': 'Vytvořit odkaz',
	'toggleDir': 'Přepnout směr',
	'insertImage': 'Vložit obrázek',
	'insertTable': 'Vložit/upravit tabulku',
	'toggleTableBorder': 'Přepnout ohraničení tabulky',
	'deleteTable': 'Odstranit tabulku',
	'tableProp': 'Vlastnost tabulky',
	'htmlToggle': 'Zdroj HTML',
	'foreColor': 'Barva popředí',
	'hiliteColor': 'Barva pozadí',
	'plainFormatBlock': 'Styl odstavce',
	'formatBlock': 'Styl odstavce',
	'fontSize': 'Velikost písma',
	'fontName': 'Název písma',
	'tabIndent': 'Odsazení tabulátoru',
	"fullScreen": "Přepnout režim celé obrazovky",
	"viewSource": "Zobrazit zdroj ve formátu HTML",
	"print": "Tisk",
	"newPage": "Nová stránka",
	/* Error messages */
	'systemShortcut': 'Akce "${0}" je v prohlížeči dostupná pouze prostřednictvím klávesové zkratky. Použijte klávesovou zkratku ${1}.'
})

==> dojo_1.7.2+dfsg.orig.tar.gz: dojo-release-1.7.2-src+dfsg/dijit/_editor/nls/cs/commands.js <==
define(
//begin v1.x content
({
	'bold': 'Tučné',
	'copy': 'Kopírovat',
	'cut': 'Vyjmout',
	'delete': 'Odstranit',
	'indent': 'Odsadit',
	'insertHorizontalRule': 'Vodorovná čára',
	'insertOrderedList': 'Číslovaný seznam',
	'insertUnorderedList': 'Seznam s odrážkami',
	'italic': 'Kurzíva',
	'justifyCenter': 'Zarovnat na střed',
	'justifyFull': 'Do bloku',
	'justifyLeft': 'Zarovnat vlevo',
	'justifyRight': 'Zarovnat vpravo',
	'outdent': 'Předsadit',
	'paste': 'Vložit',
	'redo': 'Opakovat',
	'removeFormat': 'Odebrat formát',
	'selectAll': 'Vybrat vše',
	'strikethrough': 'Přeškrtnutí',
	'subscript': 'Dolní index',
	'superscript': 'Horní index',
	'underline': 'Podtržení',
	'undo': 'Zpět',
	'unlink': 'Odebrat odkaz',
	'createLink': 'Vytvořit odkaz',
	'toggleDir': 'Přepnout směr',
	'insertImage': 'Vložit obrázek',
	'insertTable': 'Vložit/upravit tabulku',
	'toggleTableBorder': 'Přepnout ohraničení tabulky',
	'deleteTable': 'Odstranit tabulku',
	'tableProp': 'Vlastnost tabulky',
	'htmlToggle': 'Zdroj HTML',
	'foreColor': 'Barva popředí',
	'hiliteColor': 'Barva pozadí',
	'plainFormatBlock': 'Styl odstavce',
	'formatBlock': 'Styl odstavce',
	'fontSize': 'Velikost písma',
	'fontName': 'Název písma',
	'tabIndent': 'Odsazení tabulátoru',
	"fullScreen": "Přepnout celou obrazovku",
	"viewSource": "Zobrazit zdroj HTML",
	"print": "Tisk",
	"newPage": "Nová stránka",
	/* Error messages */
	'systemShortcut': 'Akce "${0}" je v prohlížeči dostupná pouze prostřednictvím klávesové zkratky. Použijte klávesovou zkratku ${1}.'
})
//end v1.x content
);
